#include "setting_win.hh"
#include <gconfmm/init.h>
#include <gtkmm/stock.h>
#include <gtkmm/label.h>

using namespace go;

void SettingWin::on_response(int r)
{
	switch ((Response) r) {
	case RE_CLOSE:
		hide();
		break;
	}
}

void SettingWin::toggle_option(Gtk::CheckButton * cb, Settings::Options o)
{
	go::settings.set_option(o, cb->get_active());
}

void SettingWin::set_image_path()
{
	go::settings.set_image_path(image_path_entry.get_text());
}

void SettingWin::set_igs_telnet()
{
	go::settings.set_igs_telnet(igs_telnet_entry.get_text());
}

SettingWin::SettingWin()
{
	set_title("ccGo properties");

	get_vbox()->pack_start(* Gtk::manage(new Gtk::Label("Property Settings")));

	Gtk::HBox * hb;
	Gtk::CheckButton * cb;

	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);
	cb = Gtk::manage(new Gtk::CheckButton("Dump all communications with IGS to stdout"));
	cb->set_active(go::settings.get_option(Settings::OPT_DUMP_IGS));
	hb->pack_start(* cb, Gtk::PACK_SHRINK);
	cb->signal_toggled().connect(SigC::bind(SigC::slot(* this, & SettingWin::toggle_option), cb, Settings::OPT_DUMP_IGS));

	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);
	cb = Gtk::manage(new Gtk::CheckButton("Show unprocessed raw messages from IGS"));
	cb->set_active(go::settings.get_option(Settings::OPT_LEAK_RAW));
	hb->pack_start(* cb, Gtk::PACK_SHRINK);
	cb->signal_toggled().connect(SigC::bind(SigC::slot(* this, & SettingWin::toggle_option), cb, Settings::OPT_LEAK_RAW));

	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);
	cb = Gtk::manage(new Gtk::CheckButton("Popup Player List on tell message"));
	cb->set_active(go::settings.get_option(Settings::OPT_POP_PLAYERS_ON_TELL));
	hb->pack_start(* cb, Gtk::PACK_SHRINK);
	cb->signal_toggled().connect(SigC::bind(SigC::slot(* this, & SettingWin::toggle_option), cb, Settings::OPT_POP_PLAYERS_ON_TELL));

	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);
	cb = Gtk::manage(new Gtk::CheckButton("Popup Player List on stats message"));
	cb->set_active(go::settings.get_option(Settings::OPT_POP_PLAYERS_ON_STATS));
	hb->pack_start(* cb, Gtk::PACK_SHRINK);
	cb->signal_toggled().connect(SigC::bind(SigC::slot(* this, & SettingWin::toggle_option), cb, Settings::OPT_POP_PLAYERS_ON_STATS));

	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);
	cb = Gtk::manage(new Gtk::CheckButton("Popup Player List on match request"));
	cb->set_active(go::settings.get_option(Settings::OPT_POP_PLAYERS_ON_MATCH));
	hb->pack_start(* cb, Gtk::PACK_SHRINK);
	cb->signal_toggled().connect(SigC::bind(SigC::slot(* this, & SettingWin::toggle_option), cb, Settings::OPT_POP_PLAYERS_ON_MATCH));

	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);
	cb = Gtk::manage(new Gtk::CheckButton("Show coordinates beside the board"));
	cb->set_active(go::settings.get_option(Settings::OPT_SHOW_COORDINATE));
	hb->pack_start(* cb, Gtk::PACK_SHRINK);
	cb->signal_toggled().connect(SigC::bind(SigC::slot(* this, & SettingWin::toggle_option), cb, Settings::OPT_SHOW_COORDINATE));

	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);
	cb = Gtk::manage(new Gtk::CheckButton("Use picture stone images"));
	cb->set_active(go::settings.get_option(Settings::OPT_PICTURE_STONE));
	hb->pack_start(* cb, Gtk::PACK_SHRINK);
	cb->signal_toggled().connect(SigC::bind(SigC::slot(* this, & SettingWin::toggle_option), cb, Settings::OPT_PICTURE_STONE));

	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);
	cb = Gtk::manage(new Gtk::CheckButton("Use picture board image"));
	cb->set_active(go::settings.get_option(Settings::OPT_PICTURE_BOARD));
	hb->pack_start(* cb, Gtk::PACK_SHRINK);
	cb->signal_toggled().connect(SigC::bind(SigC::slot(* this, & SettingWin::toggle_option), cb, Settings::OPT_PICTURE_BOARD));

	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);
	hb->pack_start(* Gtk::manage(new Gtk::Label("Path to image files: ")), Gtk::PACK_SHRINK);
	hb->pack_end(image_path_entry);
	image_path_entry.set_text(go::settings.get_image_path());
	image_path_entry.signal_changed().connect(SigC::slot(* this, & SettingWin::set_image_path));

	hb = Gtk::manage(new Gtk::HBox);
	get_vbox()->pack_start(* hb, Gtk::PACK_SHRINK);
	hb->pack_start(* Gtk::manage(new Gtk::Label("IGS telnet command: ")), Gtk::PACK_SHRINK);
	hb->pack_end(igs_telnet_entry);
	igs_telnet_entry.set_text(go::settings.get_igs_telnet());
	igs_telnet_entry.signal_changed().connect(SigC::slot(* this, & SettingWin::set_igs_telnet));

	add_button(Gtk::Stock::CLOSE, RE_CLOSE);
	show_all_children();
}

